library bloc_stream;

import 'dart:async';

import 'package:meta/meta.dart';
import 'package:rxdart/rxdart.dart';

abstract class BlocStream<State> {
  BlocStream() {
    subject = BehaviorSubject.seeded(initialValue);
  }

  /// Protected BehaviorSubject used for implementation.
  @protected
  BehaviorSubject<State> subject;

  /// Output stream to be consumed by application.
  Stream<State> get stream => subject.stream;

  State get initialValue => null;
  State get value => subject.value;

  /// Helper method to reduce boilerplate when composing BLoC's together.
  @protected
  void cancelOnClose(StreamSubscription subscription,
      [void Function() onClose]) {
    _closers.add(() {
      subscription.cancel();
      if (onClose != null) onClose();
    });
  }

  final _closers = <void Function()>[];

  @mustCallSuper
  Future<void> close() {
    _closers.forEach((fn) => fn());
    return subject.close();
  }

  StreamSubscription<State> listen(
    void Function(State) onData, {
    Function onError,
    void Function() onDone,
    bool cancelOnError,
  }) =>
      subject.listen(
        onData,
        onError: onError,
        onDone: onDone,
        cancelOnError: cancelOnError,
      );
}
